(function ($) {
  /* ********************************
   EQUAL HEIGHTS
   ******************************** */

  // Make all Field Collection items of each row equal in height.
  Drupal.behaviors.fc_styleChanges = {
    attach: function (context, settings) {
      fc_styleCollection = settings.fc_style.fc_styleStylise;
      field_collections = [];

      // Get rid of doubles.
      $.each(fc_styleCollection, function(i, el){
        if($.inArray(el, field_collections) === -1) field_collections.push(el);
      });

      // Set equal heights of Field Collections.
      function setResize() {

        // Find all Field Collections and iterate through them.
        $(function() {

          var minimumWindowWidth = 740; // Skip screens smaller than this.

          // Loop through each type of Field Collection.
          for (var i in field_collections) {
            if (isFinite(String(i))) {
              // Process all Field Collections of this type.
              $(field_collections[i]).each(function () {
                // Process a specific Field Collection instance.
                setResizedHeights(this);


                if ($(window).width() >= minimumWindowWidth) {
                  setEqualHeights(this);
                }

                //setEqualHeights(this);
              });
            }

          }
        });
      }

      // Set equal heights of items in one specific Field Collection.
      function setResizedHeights(fieldCollection) {
        // Loop through each item in a Field Collection.
        var items = $(fieldCollection).find(".fc-style-item");
        var rowTop = 0;
        var top = 0;
        var originalHeight = {};

        // Loop through each item in a Field Collection.
        for (var key in items) {

          // Check key is numeric.
          if (isFinite(String(key))) {
            $(items[key]).height('auto');
          }
        }

      }

      // Set equal heights of items in one specific Field Collection.
      function setEqualHeights(fieldCollection) {
        // Loop through each item in a Field Collection.
        var items = $(fieldCollection).find(".fc-style-item");
        var rowTop = 0;
        var top = 0;

        var currentTallest = 0;
        var rowItems = [];
        var totalItems = items.length;

        // Loop through each item in a Field Collection.
        for (var key in items) {

          // Check key is numeric.
          if (isFinite(String(key))) {

            top = $(items[key]).offset().top;

            if (rowTop != top) {
              // we just came to a new row. Set all the heights on the completed row

              // Set current item as start of row.
              $(items[key]).addClass("fc-style-item-alpha");

              // Set previous item as end of last row.
              if (key > 0) {
                // check previous item is not start of the row.
                if (!$(items[key - 1]).hasClass("fc-style-item-alpha")) {
                  $(items[key - 1]).removeClass("fc-style-item-middle");
                  $(items[key - 1]).addClass("fc-style-item-omega");
                }
              }

              // Set heights on previous row.
              for (var delta in rowItems) {
                if (isFinite(String(delta))) {
                  $(items[delta]).height(currentTallest);
                }
              }

              // set the variables for the new row
              rowItems.length = 0; // empty the array
              rowItems.push(key);
              currentTallest = 0;
              rowTop = top;

              if ($(items[key]).height() > currentTallest) {
                currentTallest = $(items[key]).height();
              }

            }
            else if (key == (totalItems - 1)) { // Last item of field_collections.
              if ($(items[key]).height() > currentTallest) {
                currentTallest = $(items[key]).height();
              }

              rowItems.push(key);

              // Set heights on previous row.
              for (var delta in rowItems) {
                if (isFinite(String(delta))) {
                  $(items[delta]).height(currentTallest);
                }
              }
            }
            else {
              // Set as middle item.
              $(items[key]).addClass("fc-style-item-middle");

              // Check if this is tallest item.
              if ($(items[key]).height() > currentTallest) {
                currentTallest = $(items[key]).height();
              }

              rowItems.push(key);
            }
          }
        }

      }

      // Change equal heights when window is resized.
      $(window).resize(function() {
        setResize();
      });

      // Set equal heights on page load.
      $(window).load(function() {
        var minimumWindowWidth = 740; // Skip screens smaller than this.

        if ($(window).width() >= minimumWindowWidth) {
          setResize();
        }
      });
    }
  };

})(jQuery);
